from office365api.model.model import Recipient
from office365api.model.model import EmailAddress
from office365api.model.model import Message
from office365api.model.model import ItemBody
from office365api.model.model import Attachment, FileAttachment, ItemAttachment
